searchData={"content_type":"text/markdown","items":[{"doc":"Defines a `t:Jellyfish.Client.t/0`.\n\nBy default, Mint adapter for [Tesla](https://github.com/elixir-tesla/tesla) is used to make HTTP requests, but it can be changed:\n```\n# config.exs\nconfig :jellyfish_server_sdk, tesla_adapter: Tesla.Adapter.Hackney\n\n# mix.exs\ndefp deps do\n  [\n    {:hackney, \"~> 1.10\"}\n  ]\nend\n```\nFor the list of supported Tesla adapters refer to [Tesla docs](https://hexdocs.pm/tesla/readme.html#adapters).","ref":"Jellyfish.Client.html","title":"Jellyfish.Client","type":"module"},{"doc":"Creates a new instance of `t:Jellyfish.Client.t/0`.\n\nFor information about options, see `t:connection_options/0`.","ref":"Jellyfish.Client.html#new/1","title":"Jellyfish.Client.new/1","type":"function"},{"doc":"Updates Jellyfish address.\n\nWhen running Jellyfish in a cluster, user has to \nmanually update Jellyfish address after creating a room.\nSee also `Jellyfish.Room.create/2`.","ref":"Jellyfish.Client.html#update_address/2","title":"Jellyfish.Client.update_address/2","type":"function"},{"doc":"Options needed to open connection to Jellyfish server.\n\n* `:server_address` - address of the Jellyfish server instance.\n* `:server_api_token` - token used for authorizing HTTP requests and WebSocket connection.\nIt's the same token as the one configured in Jellyfish.\n* `:secure?` - if `true`, use HTTPS and WSS instead of HTTP and WS, `false` by default.\n\nWhen an option is not explicily passed, value set in `config.exs` is used:\n```\n# in config.exs\nconfig :jellyfish_server_sdk,\n  server_address: \"localhost:5002\",\n  server_api_token: \"your-jellyfish-token\",\n  secure?: true\n```","ref":"Jellyfish.Client.html#t:connection_options/0","title":"Jellyfish.Client.connection_options/0","type":"type"},{"doc":"","ref":"Jellyfish.Client.html#t:t/0","title":"Jellyfish.Client.t/0","type":"type"},{"doc":"Defines `t:Jellyfish.Component.t/0`.\n\nComponent is a server-side entity that can publish, subscribe to and process tracks.\nFor more information refer to [Jellyfish documentation](https://jellyfish-dev.github.io/jellyfish-docs/introduction/basic_concepts).","ref":"Jellyfish.Component.html","title":"Jellyfish.Component","type":"module"},{"doc":"Id of the component, unique within the room.","ref":"Jellyfish.Component.html#t:id/0","title":"Jellyfish.Component.id/0","type":"type"},{"doc":"Component-specific options.","ref":"Jellyfish.Component.html#t:options/0","title":"Jellyfish.Component.options/0","type":"type"},{"doc":"Stores information about the component.","ref":"Jellyfish.Component.html#t:t/0","title":"Jellyfish.Component.t/0","type":"type"},{"doc":"Type of the component.","ref":"Jellyfish.Component.html#t:type/0","title":"Jellyfish.Component.type/0","type":"type"},{"doc":"Options for the HLS component.\n\nFor the description of these options refer to [Jellyfish\ndocumentation](https://jellyfish-dev.github.io/jellyfish-docs/getting_started/components/hls).","ref":"Jellyfish.Component.HLS.html","title":"Jellyfish.Component.HLS","type":"module"},{"doc":"","ref":"Jellyfish.Component.HLS.html#t:t/0","title":"Jellyfish.Component.HLS.t/0","type":"type"},{"doc":"Options for the RTSP component.\n\nFor the description of these options refer to [Jellyfish\ndocumentation](https://jellyfish-dev.github.io/jellyfish-docs/getting_started/components/rtsp).","ref":"Jellyfish.Component.RTSP.html","title":"Jellyfish.Component.RTSP","type":"module"},{"doc":"","ref":"Jellyfish.Component.RTSP.html#t:t/0","title":"Jellyfish.Component.RTSP.t/0","type":"type"},{"doc":"Module defining a process responsible for establishing\nWebSocket connection and receiving events from Jellyfish server.\n\nFirst, [configure the connection options](README.md#jellyfish-connection-configuration).\n\n```\n# Start the Notifier\niex> {:ok, notifier} = Jellyfish.Notifier.start()\n{:ok, #PID }\n```\n\n```\n# Subscribe current process to server notifications.\niex> :ok = Jellyfish.Notifier.subscribe_server_notifications(notifier)\n\n# here add a room and a peer using functions from `Jellyfish.Room` module\n# you should receive a notification after the peer established connection\n\niex> flush()\n{:jellyfish, %Jellyfish.Notification.PeerConnected{\n  room_id: \"21604fbe-8ac8-44e6-8474-98b5f50f1863\",\n  peer_id: \"ae07f94e-0887-44c3-81d5-bfa9eac96252\"\n}}\n:ok\n```\n\nWhen starting the Notifier, you can provide the name under which the process will be registered.\n```\niex> {:ok, notifier} = Jellyfish.Notifier.start_link(name: Jellyfish.Notifier)\n```","ref":"Jellyfish.Notifier.html","title":"Jellyfish.Notifier","type":"module"},{"doc":"Starts the Notifier process and connects to Jellyfish.\n\nTo learn how to receive notifications, see `subscribe/3`.\n\nFor information about options, see `t:Jellyfish.Client.connection_options/0`.","ref":"Jellyfish.Notifier.html#start/1","title":"Jellyfish.Notifier.start/1","type":"function"},{"doc":"Starts the Notifier process and connects to Jellyfish.\n\nActs like `start/1` but links to the calling process.\n\nSee `start/1` for more information.","ref":"Jellyfish.Notifier.html#start_link/1","title":"Jellyfish.Notifier.start_link/1","type":"function"},{"doc":"Subscribes the process to the WebRTC metrics from all the rooms.\n\nMetrics are periodically sent to the process in a form of `{:jellyfish, metrics_report}`,\nwhere `metrics_report` is the `Jellyfish.MetricsReport` struct.","ref":"Jellyfish.Notifier.html#subscribe_metrics/1","title":"Jellyfish.Notifier.subscribe_metrics/1","type":"function"},{"doc":"Subscribes the process to receive server notifications from all the rooms.\n\nNotifications are sent to the process in a form of `{:jellyfish, msg}`,\nwhere `msg` is one of structs defined under \"Jellyfish.Notification\" section in the docs,\nfor example `{:jellyfish, %Jellyfish.Notification.RoomCrashed{room_id: \"some_id\"}}`.","ref":"Jellyfish.Notifier.html#subscribe_server_notifications/1","title":"Jellyfish.Notifier.subscribe_server_notifications/1","type":"function"},{"doc":"The reference to the `Notifier` process.","ref":"Jellyfish.Notifier.html#t:notifier/0","title":"Jellyfish.Notifier.notifier/0","type":"type"},{"doc":"Connection options used to connect to Jellyfish server.","ref":"Jellyfish.Notifier.html#t:options/0","title":"Jellyfish.Notifier.options/0","type":"type"},{"doc":"Defines `t:Jellyfish.Peer.t/0`.\n\nPeer is an entity that connects to the server to publish, subscribe to or publish and subscribe\nto tracks published by components and other peers.\nFor more information refer to [Jellyfish documentation](https://jellyfish-dev.github.io/jellyfish-docs/introduction/basic_concepts).","ref":"Jellyfish.Peer.html","title":"Jellyfish.Peer","type":"module"},{"doc":"","ref":"Jellyfish.Peer.html#status_from_string/1","title":"Jellyfish.Peer.status_from_string/1","type":"function"},{"doc":"Id of the peer, unique across within the room.","ref":"Jellyfish.Peer.html#t:id/0","title":"Jellyfish.Peer.id/0","type":"type"},{"doc":"Peer-specific options.","ref":"Jellyfish.Peer.html#t:options/0","title":"Jellyfish.Peer.options/0","type":"type"},{"doc":"Status of the peer.","ref":"Jellyfish.Peer.html#t:status/0","title":"Jellyfish.Peer.status/0","type":"type"},{"doc":"Stores information about the peer.","ref":"Jellyfish.Peer.html#t:t/0","title":"Jellyfish.Peer.t/0","type":"type"},{"doc":"Type of the peer.","ref":"Jellyfish.Peer.html#t:type/0","title":"Jellyfish.Peer.type/0","type":"type"},{"doc":"Options for the WebRTC peer.\n\nFor the description of these options refer to [Jellyfish\ndocumentation](https://jellyfish-dev.github.io/jellyfish-docs/getting_started/peers/webrtc).","ref":"Jellyfish.Peer.WebRTC.html","title":"Jellyfish.Peer.WebRTC","type":"module"},{"doc":"","ref":"Jellyfish.Peer.WebRTC.html#t:t/0","title":"Jellyfish.Peer.WebRTC.t/0","type":"type"},{"doc":"Utilities for manipulating the rooms.","ref":"Jellyfish.Room.html","title":"Jellyfish.Room","type":"module"},{"doc":"```\niex> client = Jellyfish.Client.new()\niex> assert {:ok, %Jellyfish.Room{\n...>    components: [],\n...>    config: %{max_peers: 10, video_codec: nil},\n...>    peers: []\n...>  } = room, _jellyfish_address} = Jellyfish.Room.create(client, max_peers: 10)\niex> room == %Jellyfish.Room{\n...>    id: room.id,\n...>    components: [],\n...>    config: %{max_peers: 10, video_codec: nil},\n...>    peers: []}\ntrue\niex> assert {:ok,%Jellyfish.Peer{\n...>    status: :disconnected,\n...>    type: Jellyfish.Peer.WebRTC\n...> } = peer, _peer_token} = Jellyfish.Room.add_peer(client, room.id, Jellyfish.Peer.WebRTC)\niex> %Jellyfish.Peer{\n...>    id: peer.id,\n...>    status: :disconnected,\n...>    type: Jellyfish.Peer.WebRTC} == peer\ntrue\niex> :ok = Jellyfish.Room.delete(client, room.id)\n:ok\n```","ref":"Jellyfish.Room.html#module-examples","title":"Examples - Jellyfish.Room","type":"module"},{"doc":"Adds a component to the room with `room_id`.","ref":"Jellyfish.Room.html#add_component/3","title":"Jellyfish.Room.add_component/3","type":"function"},{"doc":"Adds a peer to the room with `room_id`.","ref":"Jellyfish.Room.html#add_peer/3","title":"Jellyfish.Room.add_peer/3","type":"function"},{"doc":"Creates a new room.\n\nReturns an address of Jellyfish where the room was created.\nWhen running Jellyfish in a cluster, this address might be different\nthan the one used in the initial call.\nTherefore, it is important to call `Jellyfish.Client.update_address/2`\nbefore subsequent operations like adding peers or components.","ref":"Jellyfish.Room.html#create/2","title":"Jellyfish.Room.create/2","type":"function"},{"doc":"Deletes the room with `room_id`.","ref":"Jellyfish.Room.html#delete/2","title":"Jellyfish.Room.delete/2","type":"function"},{"doc":"Deletes the component with `component_id` from the room with `room_id`.","ref":"Jellyfish.Room.html#delete_component/3","title":"Jellyfish.Room.delete_component/3","type":"function"},{"doc":"Deletes the peer with `peer_id` from the room with `room_id`.","ref":"Jellyfish.Room.html#delete_peer/3","title":"Jellyfish.Room.delete_peer/3","type":"function"},{"doc":"Gets metadata of the room with `room_id`.","ref":"Jellyfish.Room.html#get/2","title":"Jellyfish.Room.get/2","type":"function"},{"doc":"Lists metadata of all of the rooms.","ref":"Jellyfish.Room.html#get_all/1","title":"Jellyfish.Room.get_all/1","type":"function"},{"doc":"Id of the room, unique within Jellyfish instance.","ref":"Jellyfish.Room.html#t:id/0","title":"Jellyfish.Room.id/0","type":"type"},{"doc":"Type describing room options.\n\n  * `:max_peers` - maximum number of peers present in a room simultaneously.\n    If set to `nil` or unspecified, the number of peers is unlimited.\n  * `:video_codec` - enforces specific video codec for each peer in the room.\n    If set to `nil` or unspecified, any codec will be accepted.\n    To use HLS component video codec has to be `:h264`.","ref":"Jellyfish.Room.html#t:options/0","title":"Jellyfish.Room.options/0","type":"type"},{"doc":"Peer token, created by Jellyfish. Required by client application to open connection to Jellyfish.","ref":"Jellyfish.Room.html#t:peer_token/0","title":"Jellyfish.Room.peer_token/0","type":"type"},{"doc":"Stores information about the room.","ref":"Jellyfish.Room.html#t:t/0","title":"Jellyfish.Room.t/0","type":"type"},{"doc":"","ref":"Jellyfish.MetricsReport.html","title":"Jellyfish.MetricsReport","type":"module"},{"doc":"Describes a WebRTC metrics report, which is periodically sent once the process subscribes for metrics events.\n\nThe report is a map, with each entry being a `metric_name => value` pair, where value can be a boolean, number, string or a map with the same structure.\n\nHere is a sample report:\n```\n%Jellyfish.MetricsReport{\nmetrics: %{\n \"inbound-rtp.frames\" => 406,\n \"inbound-rtp.keyframes\" => 9,\n \"room_id=32b1e952-9efa-4c29-88bc-36d7a536f95a\" => %{\n   \"endpoint_id=4354f193-e787-4f07-b445-7e246b702ba6\" => %{\n     \"ice.protocol\" => \"udp\",\n     \"track_id=4354f193-e787-4f07-b445-7e246b702ba6:cd2013a8-ea9f-4612-aa99-05149172e6a5:\" => %{\n       \"inbound-rtp.bytes_received\" => 379567,\n       \"inbound-rtp.bytes_received-per-second\" => 68355.64435564436,\n       \"inbound-rtp.encoding\" => \"VP8\",\n       \"rtx_stream\" => %{\n         \"inbound-rtp.bytes_received\" => 7680,\n         \"inbound-rtp.bytes_received-per-second\" => 0.0\n       },\n       \"track.metadata\" => %{\n         \"active\" => true,\n         \"type\" => \"camera\"\n       }\n     },\n     \"track_id=5ead4135-6ab2-4872-8c04-daca02f5116d:63543a41-b3ff-4a80-91fd-91cfdea13cbe\" => %{\n       \"outbound-rtp.bytes\" => 354075,\n       \"outbound-rtp.bytes-per-second\" => 63083.91608391608,\n       \"outbound-rtp.variant\" => \"high\"\n     }\n   }\n}\n```","ref":"Jellyfish.MetricsReport.html#t:t/0","title":"Jellyfish.MetricsReport.t/0","type":"type"},{"doc":"","ref":"Jellyfish.Notification.ComponentCrashed.html","title":"Jellyfish.Notification.ComponentCrashed","type":"module"},{"doc":"","ref":"Jellyfish.Notification.ComponentCrashed.html#t:t/0","title":"Jellyfish.Notification.ComponentCrashed.t/0","type":"type"},{"doc":"","ref":"Jellyfish.Notification.HlsPlayable.html","title":"Jellyfish.Notification.HlsPlayable","type":"module"},{"doc":"","ref":"Jellyfish.Notification.HlsPlayable.html#t:t/0","title":"Jellyfish.Notification.HlsPlayable.t/0","type":"type"},{"doc":"","ref":"Jellyfish.Notification.PeerConnected.html","title":"Jellyfish.Notification.PeerConnected","type":"module"},{"doc":"","ref":"Jellyfish.Notification.PeerConnected.html#t:t/0","title":"Jellyfish.Notification.PeerConnected.t/0","type":"type"},{"doc":"","ref":"Jellyfish.Notification.PeerCrashed.html","title":"Jellyfish.Notification.PeerCrashed","type":"module"},{"doc":"","ref":"Jellyfish.Notification.PeerCrashed.html#t:t/0","title":"Jellyfish.Notification.PeerCrashed.t/0","type":"type"},{"doc":"","ref":"Jellyfish.Notification.PeerDisconnected.html","title":"Jellyfish.Notification.PeerDisconnected","type":"module"},{"doc":"","ref":"Jellyfish.Notification.PeerDisconnected.html#t:t/0","title":"Jellyfish.Notification.PeerDisconnected.t/0","type":"type"},{"doc":"","ref":"Jellyfish.Notification.RoomCrashed.html","title":"Jellyfish.Notification.RoomCrashed","type":"module"},{"doc":"","ref":"Jellyfish.Notification.RoomCrashed.html#t:t/0","title":"Jellyfish.Notification.RoomCrashed.t/0","type":"type"},{"doc":"","ref":"Jellyfish.Notification.RoomCreated.html","title":"Jellyfish.Notification.RoomCreated","type":"module"},{"doc":"","ref":"Jellyfish.Notification.RoomCreated.html#t:t/0","title":"Jellyfish.Notification.RoomCreated.t/0","type":"type"},{"doc":"","ref":"Jellyfish.Notification.RoomDeleted.html","title":"Jellyfish.Notification.RoomDeleted","type":"module"},{"doc":"","ref":"Jellyfish.Notification.RoomDeleted.html#t:t/0","title":"Jellyfish.Notification.RoomDeleted.t/0","type":"type"},{"doc":"","ref":"Jellyfish.Exception.ProtocolPrefixError.html","title":"Jellyfish.Exception.ProtocolPrefixError","type":"exception"},{"doc":"","ref":"Jellyfish.Exception.StructureError.html","title":"Jellyfish.Exception.StructureError","type":"exception"},{"doc":"# Jellyfish Elixir Server SDK\n\n[![Hex.pm](https://img.shields.io/hexpm/v/jellyfish_server_sdk.svg)](https://hex.pm/packages/jellyfish_server_sdk)\n[![API Docs](https://img.shields.io/badge/api-docs-yellow.svg?style=flat)](https://hexdocs.pm/jellyfish_server_sdk/)\n[![codecov](https://codecov.io/gh/jellyfish-dev/elixir_server_sdk/branch/master/graph/badge.svg?token=ByIko4o5U8)](https://codecov.io/gh/jellyfish-dev/elixir_server_sdk)\n[![CircleCI](https://circleci.com/gh/jellyfish-dev/elixir_server_sdk.svg?style=svg)](https://circleci.com/gh/jellyfish-dev/elixir_server_sdk)\n\nElixir server SDK for [Jellyfish](https://github.com/jellyfish-dev/jellyfish).\nCurrently it allows for:\n\n- making API calls to Jellyfish server (QoL wrapper for HTTP requests)\n- listening to Jellyfish server events via WebSocket","ref":"readme.html","title":"Jellyfish Elixir Server SDK","type":"extras"},{"doc":"The package can be installed by adding `jellyfish_server_sdk` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:jellyfish_server_sdk, \"~> 0.2.0\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - Jellyfish Elixir Server SDK","type":"extras"},{"doc":"Define the connection configuration in the mix config,\nspecifying server address and authentication token\n(for more information see [Jellyfish docs](https://jellyfish-dev.github.io/jellyfish-docs/getting_started/authentication))\n``` config.exs\nconfig :jellyfish_server_sdk,\n  server_address: \"localhost:5002\",\n  server_api_token: \"your-jellyfish-token\",\n  secure?: true\n```\n\nAlternatively, the connection options can be provided when creating a `Jellyfish.Client` or starting `Jellyfish.Notifier`:\n\n```elixir\nclient =\n    Jellyfish.Client.new(server_address: \"localhost:5002\", server_api_token: \"your-jellyfish-token\")\n\n{:ok, notifier} =\n    Jellyfish.Notifier.start(\n      server_address: \"localhost:5002\",\n      server_api_token: \"your-jellyfish-token\"\n    )\n```","ref":"readme.html#jellyfish-connection-configuration","title":"Jellyfish connection configuration - Jellyfish Elixir Server SDK","type":"extras"},{"doc":"Make API calls to Jellyfish and receive server events:\n\n```elixir\n# start process responsible for receiving events\n{:ok, notifier} = Jellyfish.Notifier.start()\n:ok = Jellyfish.Notifier.subscribe_server_notifications(notifier)\n\n# create HTTP client instance\nclient = Jellyfish.Client.new()\n\n# Create room\n{:ok, %Jellyfish.Room{id: room_id}, jellyfish_address} = Jellyfish.Room.create(client, max_peers: 10)\n\nroom_id\n# => \"8878cd13-99a6-40d6-8d7e-8da23d803dab\"\n\n# Add peer\n{:ok, %Jellyfish.Peer{id: peer_id}, peer_token} =\n    Jellyfish.Room.add_peer(client, room_id, Jellyfish.Peer.WebRTC)\n\nreceive do\n  {:jellyfish, %Jellyfish.Notification.PeerConnected{room_id: ^room_id, peer_id: ^peer_id}} ->\n    # handle the notification\nend\n\n# Delete peer\n:ok = Jellyfish.Room.delete_peer(client, room_id, peer_id)\n```\n\nList of structs representing events can be found in the [docs](https://hexdocs.pm/jellyfish_server_sdk).","ref":"readme.html#usage","title":"Usage - Jellyfish Elixir Server SDK","type":"extras"},{"doc":"When calling `mix test` it will automatically start the Jellyfish container under the hood.\nTests on CI are run with the use of docker-compose, to run it locally in the same way as on CI run `mix integration_test`.","ref":"readme.html#testing","title":"Testing - Jellyfish Elixir Server SDK","type":"extras"},{"doc":"Copyright 2023, [Software Mansion](https://swmansion.com/?utm_source=git&utm_medium=readme&utm_campaign=jellyfish)\n\n[![Software Mansion](https://logo.swmansion.com/logo?color=white&variant=desktop&width=200&tag=membrane-github)](https://swmansion.com/?utm_source=git&utm_medium=readme&utm_campaign=jellyfish)\n\nLicensed under the [Apache License, Version 2.0](LICENSE)","ref":"readme.html#copyright-and-license","title":"Copyright and License - Jellyfish Elixir Server SDK","type":"extras"},{"doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS\n\n   APPENDIX: How to apply the Apache License to your work.\n\n      To apply the Apache License to your work, attach the following\n      boilerplate notice, with the fields enclosed by brackets \"[]\"\n      replaced with your own identifying information. (Don't include\n      the brackets!)  The text should be enclosed in the appropriate\n      comment syntax for the file format. We also recommend that a\n      file or class name and description of purpose be included on the\n      same \"printed page\" as the copyright notice for easier\n      identification within third-party archives.\n\n   Copyright 2022 Software Mansion\n\n   Licensed under the Apache License, Version 2.0 (the \"License\");\n   you may not use this file except in compliance with the License.\n   You may obtain a copy of the License at\n\n       http://www.apache.org/licenses/LICENSE-2.0\n\n   Unless required by applicable law or agreed to in writing, software\n   distributed under the License is distributed on an \"AS IS\" BASIS,\n   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n   See the License for the specific language governing permissions and\n   limitations under the License.","ref":"license.html","title":"LICENSE","type":"extras"}]}